@@ -1,7 +1,7 @@
 /* snac - A simple, minimalistic ActivityPub instance */
 /* copyright (c) 2022 - 2026 grunfink et al. / MIT license */
 
-#define VERSION "2.88"
+#define VERSION "2.90"
 
 #define USER_AGENT "snac/" VERSION
 
@@ -35,10 +35,12 @@ extern xs_dict *srv_config;
 extern xs_str *srv_baseurl;
 extern xs_str *srv_proxy_token_seed;
 extern xs_dict *srv_langs;
+extern const char *months[12];
 
 extern int dbglevel;
 
 #define L(s) lang_str((s), user)
+#define LL(s) (s)
 
 #define POSTLIKE_OBJECT_TYPE "Note|Question|Page|Article|Video|Audio|Event"
 
@@ -105,6 +107,7 @@ int validate_uid(const char *uid);
 xs_str *hash_password(const char *uid, const char *passwd, const char *nonce);
 int check_password(const char *uid, const char *passwd, const char *hash);
 
+char* findprog(const char *prog);
 int strip_media(const char *fn);
 int check_strip_tool(void);
 
@@ -277,6 +280,7 @@ void notify_add(snac *snac, const char *type, const char *utype,
 xs_dict *notify_get(snac *snac, const char *id);
 int notify_new_num(snac *snac);
 xs_list *notify_list(snac *snac, int skip, int show);
+xs_list *notify_filter_list(snac *snac, xs_list *ids);
 void notify_clear(snac *snac);
 
 xs_dict *markers_get(snac *snac, const xs_list *markers);
